async function checkIDCard(idcode) {
    // 加权因子
    const weight_factor = [ 7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2 ];
    // 校验码
    const check_code = [ '1', '0', 'X', '9', '8', '7', '6', '5', '4', '3', '2' ];

    const code = idcode + '';
    const last = idcode[17];// 最后一位

    const seventeen = code.substring(0, 17);

    // ISO 7064:1983.MOD 11-2
    // 判断最后一位校验码是否正确
    const arr = seventeen.split('');
    const len = arr.length;
    let num = 0;
    for (let i = 0; i < len; i++) {
        num = num + arr[i] * weight_factor[i];
    }

    // 获取余数
    const resisue = num % 11;
    const last_no = check_code[resisue];

    // 格式的正则
    // 正则思路
    /*
          第一位不可能是0
          第二位到第六位可以是0-9
          第七位到第十位是年份，所以七八位为19或者20
          十一位和十二位是月份，这两位是01-12之间的数值
          十三位和十四位是日期，是从01-31之间的数值
          十五，十六，十七都是数字0-9
          十八位可能是数字0-9，也可能是X
          */
    const idcard_patter = /^[1-9][0-9]{5}([1][9][0-9]{2}|[2][0][0|1][0-9])([0][1-9]|[1][0|1|2])([0][1-9]|[1|2][0-9]|[3][0|1])[0-9]{3}([0-9]|[X])$/;

    // 判断格式是否正确
    const format = idcard_patter.test(idcode);

    // 返回验证结果，校验码和格式同时正确才算是合法的身份证号码
    return !!(last === last_no && format);
}



export const idCard = (rule, value, callback) => {
    if(value === ''){
        callback(new Error("请输入身份证号"));
    }
    if(value){
        if (isSFZH(value)) {
            const dateMat = new Date();
            const year = dateMat.getFullYear();
            const month =
                dateMat.getMonth() + 1 > 9
                    ? dateMat.getMonth() + 1
                    : "0" + (dateMat.getMonth() + 1);
            const day =
                dateMat.getDate() > 9 ? dateMat.getDate() : "0" + dateMat.getDate();
            const newTime = window.parseInt("" + year + month + day)
            let cIdNum1 = newTime - 60 * 10000;
            let cIdNum3 = newTime - 150 * 10000;
            if(cIdNum1 < window.parseInt(value.substr(6, 8))){
                callback(new Error("老人年龄不能小于60周岁"));
            }else if (cIdNum3 > window.parseInt(value.substr(6, 8))){
                callback(new Error("老人年龄不能超过150周岁"));
            }else {
                callback();
            }
        } else {
            callback(new Error('证件号码格式不正确'));
        }
    } else{
        callback()
    }
}

function isSFZH(id) {
    if (id == null || id == "") {
        return true;
    }

    if (id.length == 15) {
        if (isNaN(id)) {
            return false;
        }
        if (id.substring(8, 10) > 12 || id.substring(10, 12) > 31) {
            return false;
        }
    }
    else if (id.length == 18) {
        if (isNaN(id.substring(0, 17)) || (isNaN(id.substring(17, 18)) && id.substring(17, 18).toLowerCase() != "x")) {
            return false;
        }

        if (id.substring(10, 12) > 12 || id.substring(12, 14) > 31) {
            return false;
        }
        //校验最后一位校验位
        if (!CheckTheEighteenth(id)) {
            return false;
        }
    }
    else {
        return false;
    }
    return true;
}
function CheckTheEighteenth(SFZH) {
    var CheckCode; //保存最后一位
    var OtherCode;  //保存其余位
    var Sum = 0;          //保存计数和
    var TempCode;
    var S = new Array('1', '0', 'X', '9', '8', '7', '6', '5', '4', '3', '2');
    var N = new Array(7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2, 1);

    OtherCode = SFZH.substring(0, 17);

    CheckCode = SFZH.substring(17, 18);

    for (var i = 0; i < 17; i++) {
        TempCode = OtherCode.substring(i, i + 1);

        Sum += parseInt(TempCode) * N[i];
    }
    if (S[Sum % 11] == CheckCode) {
        return true;
    } else {
        return false;
    }
}
